| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Cryptol.ModuleSystem.NamingEnv.Types
Documentation
The NamingEnv is used by the renamer to determine what
identifiers refer to.
Instances
consToValues :: NamingEnv -> NamingEnv Source #
Move names in the constructor namespace to the value namespace. This is handy when checking for ambiguities.