cryptol-3.5.0: Cryptol: The Language of Cryptography
Safe HaskellNone
LanguageHaskell2010

Cryptol.Project.Cache

Synopsis

Documentation

type CacheId = ByteString Source #

This is something to identify a particular cache state. We use a hash of the cache file at the moment.

newtype LoadCache Source #

The load cache. This is what persists across invocations.

Instances

Instances details
Read LoadCache Source # 
Instance details

Defined in Cryptol.Project.Cache

Show LoadCache Source # 
Instance details

Defined in Cryptol.Project.Cache

FromValue LoadCache Source # 
Instance details

Defined in Cryptol.Project.Cache

ToTable LoadCache Source # 
Instance details

Defined in Cryptol.Project.Cache

Methods

toTable :: LoadCache -> Table #

ToValue LoadCache Source # 
Instance details

Defined in Cryptol.Project.Cache

data CacheEntry Source #

Constructors

CacheEntry 

Fields

data FullFingerprint Source #

The full fingerprint hashes the module, but also the contents of included files and foreign libraries.

metaDir :: FilePath Source #

Directory where to store the project state. XXX: This should probably be a parameter

loadLoadCache :: IO (LoadCache, CacheId) Source #

Load a cache. Also returns an id for the cache. If there is no cache (or it failed to load), then we return an empty id.

saveLoadCache :: LoadCache -> IO ByteString Source #

Save the cache. Returns an id for the cache.