| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
Cryptol.TypeCheck.Error
Synopsis
- cleanupErrors :: [(Range, Error)] -> [(Range, Error)]
- cleanupWarnings :: [(Range, Warning)] -> [(Range, Warning)]
- subsumes :: (Range, Error) -> (Range, Error) -> Bool
- data Warning
- data Error
- = KindMismatch (Maybe TypeSource) Kind Kind
- | TooManyTypeParams Int Kind
- | TyVarWithParams
- | TooManyTySynParams Name Int
- | TooFewTyParams Name Int
- | RecursiveTypeDecls [Name]
- | TooManyParams Name Type Int Int
- | ClassNotDerivable Name String [PC]
- | DerivingMissingSuperclasses PC [PC]
- | TypeMismatch TypeSource Path Type Type
- | EnumTypeMismatch Type
- | SchemaMismatch Ident Schema Schema
- | RecursiveType TypeSource Path Type Type
- | UnsolvedGoals [Goal]
- | UnsolvableGoals [Goal]
- | UnsolvedDelayedCt DelayedCt
- | UnexpectedTypeWildCard
- | TypeVariableEscaped TypeSource Path Type [TParam]
- | NotForAll TypeSource Path TVar Type
- | TooManyPositionalTypeParams
- | BadParameterKind TParam Kind [Kind]
- | CannotMixPositionalAndNamedTypeParams
- | UndefinedTypeParameter (Located Ident)
- | RepeatedTypeParameter Ident [Range]
- | AmbiguousSize TVarInfo (Maybe Type)
- | BareTypeApp
- | UndefinedExistVar Name
- | TypeShadowing String Name String
- | MissingModTParam (Located Ident)
- | MissingModVParam (Located Ident)
- | MissingModParam Ident
- | FunctorInstanceMissingArgument Ident
- | FunctorInstanceBadArgument Ident
- | FunctorInstanceMissingName Namespace Ident
- | FunctorInstanceBadBacktick BadBacktickInstance
- | UnsupportedFFIKind TypeSource TParam Kind
- | UnsupportedFFIType TypeSource FFITypeError
- | InvalidConstraintGuard Prop
- | InvalidConPat Int Int
- | UncoveredConPat [Name]
- | OverlappingPat (Maybe Ident) [Range]
- | TemporaryError Doc
- data BadBacktickInstance
- data BIWhat
- errorImportance :: Error -> Int
- explainUnsolvable :: NameMap -> [Goal] -> Doc
- computeFreeVarNames :: PPCfg -> [(Range, Warning)] -> [(Range, Error)] -> NameMap
Documentation
cleanupWarnings :: [(Range, Warning)] -> [(Range, Warning)] Source #
Clean up warning messages by sorting them by source location
(they are accumulated in reverse order by recordWarning).
subsumes :: (Range, Error) -> (Range, Error) -> Bool Source #
Should the first error suppress the next one.
Constructors
| DefaultingKind (TParam Name) Kind | |
| DefaultingWildType Kind | |
| DefaultingTo !TVarInfo Type | |
| NonExhaustivePropGuards Name | |
| DuplicateDeriving PC |
Instances
Various errors that might happen during type checking/inference
Constructors
| KindMismatch (Maybe TypeSource) Kind Kind | Expected kind, inferred kind |
| TooManyTypeParams Int Kind | Number of extra parameters, kind of result
(which should not be of the form |
| TyVarWithParams | A type variable was applied to some arguments. |
| TooManyTySynParams Name Int | Type-synonym, number of extra params |
| TooFewTyParams Name Int | Who is missing params, number of missing params |
| RecursiveTypeDecls [Name] | The type synonym declarations are recursive |
| TooManyParams Name Type Int Int | Name of bind, bind signature, number of patterns given, expected number of parameters from signature. More patterns provided for a bind than expected, given its signature. |
| ClassNotDerivable | Deriving unsupported typeclass |
| DerivingMissingSuperclasses | Deriving instance for a class without deriving instances for its superclasses |
| TypeMismatch TypeSource Path Type Type | Expected type, inferred type |
| EnumTypeMismatch Type | Expected an enum type, but inferred the supplied |
| SchemaMismatch Ident Schema Schema | Name of module parameter, expected scehema, actual schema. This may happen when instantiating modules. |
| RecursiveType TypeSource Path Type Type | Unification results in a recursive type |
| UnsolvedGoals [Goal] | A constraint that we could not solve, usually because there are some left-over variables that we could not infer. |
| UnsolvableGoals [Goal] | A constraint that we could not solve and we know it is impossible to do it. |
| UnsolvedDelayedCt DelayedCt | A constraint (with context) that we could not solve |
| UnexpectedTypeWildCard | Type wild cards are not allowed in this context (e.g., definitions of type synonyms). |
| TypeVariableEscaped TypeSource Path Type [TParam] | Unification variable depends on quantified variables that are not in scope. |
| NotForAll TypeSource Path TVar Type | Quantified type variables (of kind *) need to match the given type, so it does not work for all types. |
| TooManyPositionalTypeParams | Too many positional type arguments, in an explicit type instantiation |
| BadParameterKind TParam Kind [Kind] | We expected one of the kinds in the list, but got the given one instead. |
| CannotMixPositionalAndNamedTypeParams | |
| UndefinedTypeParameter (Located Ident) | |
| RepeatedTypeParameter Ident [Range] | |
| AmbiguousSize TVarInfo (Maybe Type) | Could not determine the value of a numeric type variable, but we know it must be at least as large as the given type (or unconstrained, if Nothing). |
| BareTypeApp | Bare expression of the form `{_} |
| UndefinedExistVar Name | |
| TypeShadowing String Name String | |
| MissingModTParam (Located Ident) | |
| MissingModVParam (Located Ident) | |
| MissingModParam Ident | |
| FunctorInstanceMissingArgument Ident | |
| FunctorInstanceBadArgument Ident | |
| FunctorInstanceMissingName Namespace Ident | |
| FunctorInstanceBadBacktick BadBacktickInstance | |
| UnsupportedFFIKind TypeSource TParam Kind | Kind is not supported for FFI |
| UnsupportedFFIType TypeSource FFITypeError | Type is not supported for FFI |
| InvalidConstraintGuard Prop | The given constraint may not be used as a constraint guard |
| InvalidConPat Int Int | Bad constructor pattern. 1) Number of parameters we have, 2) Number of parameters we need. |
| UncoveredConPat [Name] | A |
| OverlappingPat (Maybe Ident) [Range] | Overlapping patterns in a case |
| TemporaryError Doc | This is for errors that don't fit other cateogories. We should not use it much, and is generally to be used for transient errors, which are due to incomplete implementation. |
Instances
| Generic Error Source # | |||||
Defined in Cryptol.TypeCheck.Error Associated Types
| |||||
| Show Error Source # | |||||
| TVars Error Source # | |||||
| FVS Error Source # | |||||
| PP Error Source # | |||||
| NFData Error Source # | |||||
Defined in Cryptol.TypeCheck.Error | |||||
| PP (WithNames Error) Source # | |||||
| type Rep Error Source # | |||||
Defined in Cryptol.TypeCheck.Error type Rep Error = D1 ('MetaData "Error" "Cryptol.TypeCheck.Error" "cryptol-3.5.0-HoSGjqdyafy4TMoEJgOBMg" 'False) (((((C1 ('MetaCons "KindMismatch" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe TypeSource)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Kind) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Kind))) :+: C1 ('MetaCons "TooManyTypeParams" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Kind))) :+: (C1 ('MetaCons "TyVarWithParams" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "TooManyTySynParams" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Name) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int)) :+: C1 ('MetaCons "TooFewTyParams" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Name) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int))))) :+: ((C1 ('MetaCons "RecursiveTypeDecls" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Name])) :+: C1 ('MetaCons "TooManyParams" 'PrefixI 'False) ((S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Name) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int)))) :+: (C1 ('MetaCons "ClassNotDerivable" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Name) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 String) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [PC]))) :+: (C1 ('MetaCons "DerivingMissingSuperclasses" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 PC) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [PC])) :+: C1 ('MetaCons "TypeMismatch" 'PrefixI 'False) ((S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TypeSource) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Path)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type))))))) :+: (((C1 ('MetaCons "EnumTypeMismatch" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type)) :+: C1 ('MetaCons "SchemaMismatch" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Schema) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Schema)))) :+: (C1 ('MetaCons "RecursiveType" 'PrefixI 'False) ((S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TypeSource) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Path)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type))) :+: (C1 ('MetaCons "UnsolvedGoals" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Goal])) :+: C1 ('MetaCons "UnsolvableGoals" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Goal]))))) :+: ((C1 ('MetaCons "UnsolvedDelayedCt" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 DelayedCt)) :+: (C1 ('MetaCons "UnexpectedTypeWildCard" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "TypeVariableEscaped" 'PrefixI 'False) ((S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TypeSource) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Path)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [TParam]))))) :+: (C1 ('MetaCons "NotForAll" 'PrefixI 'False) ((S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TypeSource) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Path)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TVar) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Type))) :+: (C1 ('MetaCons "TooManyPositionalTypeParams" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "BadParameterKind" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TParam) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Kind) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Kind])))))))) :+: ((((C1 ('MetaCons "CannotMixPositionalAndNamedTypeParams" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "UndefinedTypeParameter" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Located Ident)))) :+: (C1 ('MetaCons "RepeatedTypeParameter" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Range])) :+: (C1 ('MetaCons "AmbiguousSize" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TVarInfo) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Type))) :+: C1 ('MetaCons "BareTypeApp" 'PrefixI 'False) (U1 :: Type -> Type)))) :+: ((C1 ('MetaCons "UndefinedExistVar" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Name)) :+: C1 ('MetaCons "TypeShadowing" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 String) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Name) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 String)))) :+: (C1 ('MetaCons "MissingModTParam" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Located Ident))) :+: (C1 ('MetaCons "MissingModVParam" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Located Ident))) :+: C1 ('MetaCons "MissingModParam" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident)))))) :+: (((C1 ('MetaCons "FunctorInstanceMissingArgument" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident)) :+: C1 ('MetaCons "FunctorInstanceBadArgument" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident))) :+: (C1 ('MetaCons "FunctorInstanceMissingName" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Namespace) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident)) :+: (C1 ('MetaCons "FunctorInstanceBadBacktick" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 BadBacktickInstance)) :+: C1 ('MetaCons "UnsupportedFFIKind" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TypeSource) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TParam) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Kind)))))) :+: ((C1 ('MetaCons "UnsupportedFFIType" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 TypeSource) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 FFITypeError)) :+: (C1 ('MetaCons "InvalidConstraintGuard" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Prop)) :+: C1 ('MetaCons "InvalidConPat" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Int)))) :+: (C1 ('MetaCons "UncoveredConPat" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Name])) :+: (C1 ('MetaCons "OverlappingPat" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Ident)) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [Range])) :+: C1 ('MetaCons "TemporaryError" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Doc)))))))) | |||||
data BadBacktickInstance Source #
Constructors
| BIPolymorphicArgument Ident Ident | |
| BINested [(BIWhat, Name)] | |
| BIMultipleParams Ident |
Instances
| Generic BadBacktickInstance Source # | |||||
Defined in Cryptol.TypeCheck.Error Associated Types
Methods from :: BadBacktickInstance -> Rep BadBacktickInstance x # to :: Rep BadBacktickInstance x -> BadBacktickInstance # | |||||
| Show BadBacktickInstance Source # | |||||
Defined in Cryptol.TypeCheck.Error Methods showsPrec :: Int -> BadBacktickInstance -> ShowS # show :: BadBacktickInstance -> String # showList :: [BadBacktickInstance] -> ShowS # | |||||
| NFData BadBacktickInstance Source # | |||||
Defined in Cryptol.TypeCheck.Error Methods rnf :: BadBacktickInstance -> () # | |||||
| type Rep BadBacktickInstance Source # | |||||
Defined in Cryptol.TypeCheck.Error type Rep BadBacktickInstance = D1 ('MetaData "BadBacktickInstance" "Cryptol.TypeCheck.Error" "cryptol-3.5.0-HoSGjqdyafy4TMoEJgOBMg" 'False) (C1 ('MetaCons "BIPolymorphicArgument" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident)) :+: (C1 ('MetaCons "BINested" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 [(BIWhat, Name)])) :+: C1 ('MetaCons "BIMultipleParams" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Ident)))) | |||||
Constructors
| BIFunctor | |
| BIInterface | |
| BIPrimitive | |
| BIForeign | |
| BIAbstractType |
Instances
| Generic BIWhat Source # | |||||
Defined in Cryptol.TypeCheck.Error Associated Types
| |||||
| Show BIWhat Source # | |||||
| NFData BIWhat Source # | |||||
Defined in Cryptol.TypeCheck.Error | |||||
| type Rep BIWhat Source # | |||||
Defined in Cryptol.TypeCheck.Error type Rep BIWhat = D1 ('MetaData "BIWhat" "Cryptol.TypeCheck.Error" "cryptol-3.5.0-HoSGjqdyafy4TMoEJgOBMg" 'False) ((C1 ('MetaCons "BIFunctor" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "BIInterface" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "BIPrimitive" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "BIForeign" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "BIAbstractType" 'PrefixI 'False) (U1 :: Type -> Type)))) | |||||
errorImportance :: Error -> Int Source #
When we have multiple errors on the same location, we show only the ones with the has highest rating according to this function.