| Copyright | (c) 2013-2016 Galois Inc. |
|---|---|
| License | BSD3 |
| Maintainer | cryptol@galois.com |
| Stability | provisional |
| Portability | portable |
| Safe Haskell | Safe |
| Language | Haskell2010 |
Cryptol.TypeCheck.PP
Description
Synopsis
Documentation
This packages together a type with some names to be used to display the variables. It is used for pretty printing types.
Instances
| PP (WithNames Decl) Source # | |
| PP (WithNames DeclDef) Source # | |
| PP (WithNames DeclGroup) Source # | |
| PP (WithNames Expr) Source # | |
| PP (WithNames Match) Source # | |
| PP n => PP (WithNames (ModuleG n)) Source # | |
| PP (WithNames TCTopEntity) Source # | |
Defined in Cryptol.TypeCheck.AST | |
| PP (WithNames Error) Source # | |
| PP (WithNames Warning) Source # | |
| PP (WithNames FFITypeError) Source # | |
Defined in Cryptol.TypeCheck.FFI.Error | |
| PP (WithNames FFITypeErrorReason) Source # | |
Defined in Cryptol.TypeCheck.FFI.Error | |
| PP (WithNames DelayedCt) Source # | |
| PP (WithNames Goal) Source # | |
| PP (WithNames Subst) Source # | |
| PP (WithNames NominalType) Source # | |
Defined in Cryptol.TypeCheck.Type | |
| PP (WithNames Schema) Source # | |
| PP (WithNames TParam) Source # | |
| PP (WithNames TVar) Source # | |
| PP (WithNames TySyn) Source # | |
| PP (WithNames Type) Source # | The precedence levels used by this pretty-printing instance correspond with parser non-terminals as follows:
|
nameList :: [String] -> [String] Source #
Expand a list of base names into an infinite list of variations.
module Cryptol.Utils.PP